==> application-ui-container-v2.2.1-2.tar.gz: package/lib/AcmProvider/index.js <==
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var _a, _b, _c;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProviderIconMap = exports.ProviderLongTextMap = exports.ProviderShortTextMap = exports.Provider = void 0;
var AcmIcons_1 = require("../AcmIcons/AcmIcons");
__exportStar(require("./AcmProviderCard/AcmProviderCard"), exports);
__exportStar(require("./AcmInlineProvider/AcmInlineProvider"), exports);
var Provider;
(function (Provider) {
    Provider["redhatcloud"] = "redhatcloud";
    Provider["aws"] = "aws";
    Provider["gcp"] = "gcp";
    Provider["azure"] = "azure";
    Provider["vmware"] = "vmware";
    Provider["ibm"] = "ibm";
    Provider["baremetal"] = "baremetal";
    Provider["other"] = "other";
})(Provider = exports.Provider || (exports.Provider = {}));
exports.ProviderShortTextMap = (_a = {},
    _a[Provider.redhatcloud] = 'cloud.redhat.com',
    _a[Provider.aws] = 'Amazon',
    _a[Provider.gcp] = 'Google',
    _a[Provider.azure] = 'Microsoft',
    _a[Provider.ibm] = 'IBM',
    _a[Provider.baremetal] = 'Bare metal',
    _a[Provider.vmware] = 'VMware',
    _a[Provider.other] = 'Other',
    _a);
exports.ProviderLongTextMap = (_b = {},
    _b[Provider.redhatcloud] = 'cloud.redhat.com',
    _b[Provider.aws] = 'Amazon Web Services',
    _b[Provider.gcp] = 'Google Cloud Platform',
    _b[Provider.azure] = 'Microsoft Azure',
    _b[Provider.ibm] = 'IBM Cloud',
    _b[Provider.baremetal] = 'Bare Metal',
    _b[Provider.vmware] = 'VMware vSphere',
    _b[Provider.other] = 'Other',
    _b);
exports.ProviderIconMap = (_c = {},
    _c[Provider.redhatcloud] = AcmIcons_1.AcmIconVariant.redhat,
    _c[Provider.aws] = AcmIcons_1.AcmIconVariant.aws,
    _c[Provider.gcp] = AcmIcons_1.AcmIconVariant.gcp,
    _c[Provider.azure] = AcmIcons_1.AcmIconVariant.azure,
    _c[Provider.ibm] = AcmIcons_1.AcmIconVariant.ibm,
    _c[Provider.baremetal] = AcmIcons_1.AcmIconVariant.baremetal,
    _c[Provider.vmware] = AcmIcons_1.AcmIconVariant.vmware,
    _c[Provider.other] = AcmIcons_1.AcmIconVariant.cloud,
    _c);
//# sourceMappingURL=index.js.map

==> application-ui-container-v2.4.4-3.tar.gz: package/lib/AcmProvider/index.js <==
"use strict";
/* Copyright Contributors to the Open Cluster Management project */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var _a, _b, _c;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProviderIconMap = exports.ProviderLongTextMap = exports.ProviderShortTextMap = exports.Provider = void 0;
var AcmIcons_1 = require("../AcmIcons/AcmIcons");
__exportStar(require("./AcmProviderCard/AcmProviderCard"), exports);
__exportStar(require("./AcmInlineProvider/AcmInlineProvider"), exports);
// These connect change as they are used in existing resources ass identifiers
var Provider;
(function (Provider) {
    Provider["redhatcloud"] = "rhocm";
    Provider["ansible"] = "ans";
    Provider["openstack"] = "ost";
    Provider["aws"] = "aws";
    Provider["gcp"] = "gcp";
    Provider["azure"] = "azr";
    Provider["vmware"] = "vmw";
    Provider["ibm"] = "ibm";
    Provider["ibmpower"] = "ibmpower";
    Provider["ibmz"] = "ibmz";
    Provider["baremetal"] = "bmc";
    Provider["hybrid"] = "hybrid";
    Provider["other"] = "other";
})(Provider = exports.Provider || (exports.Provider = {}));
exports.ProviderShortTextMap = (_a = {},
    _a[Provider.redhatcloud] = 'OCM',
    _a[Provider.ansible] = 'ANS',
    _a[Provider.openstack] = 'OpenStack',
    _a[Provider.aws] = 'Amazon',
    _a[Provider.gcp] = 'Google',
    _a[Provider.azure] = 'Microsoft',
    _a[Provider.ibm] = 'IBM',
    _a[Provider.ibmpower] = 'IBM Power',
    _a[Provider.ibmz] = 'IBM Z',
    _a[Provider.baremetal] = 'Bare metal',
    _a[Provider.vmware] = 'VMware',
    _a[Provider.hybrid] = 'On Premise',
    _a[Provider.other] = 'Other',
    _a);
exports.ProviderLongTextMap = (_b = {},
    _b[Provider.redhatcloud] = 'Red Hat OpenShift Cluster Manager',
    _b[Provider.ansible] = 'Red Hat Ansible Automation Platform',
    _b[Provider.openstack] = 'Red Hat OpenStack Platform',
    _b[Provider.aws] = 'Amazon Web Services',
    _b[Provider.gcp] = 'Google Cloud Platform',
    _b[Provider.azure] = 'Microsoft Azure',
    _b[Provider.ibm] = 'IBM Cloud',
    _b[Provider.ibmpower] = 'IBM Power',
    _b[Provider.ibmz] = 'IBM Z',
    _b[Provider.baremetal] = 'Bare metal',
    _b[Provider.vmware] = 'VMware vSphere',
    _b[Provider.hybrid] = 'On Premise',
    _b[Provider.other] = 'Other',
    _b);
exports.ProviderIconMap = (_c = {},
    _c[Provider.redhatcloud] = AcmIcons_1.AcmIconVariant.redhat,
    _c[Provider.ansible] = AcmIcons_1.AcmIconVariant.ansible,
    _c[Provider.openstack] = AcmIcons_1.AcmIconVariant.redhat,
    _c[Provider.aws] = AcmIcons_1.AcmIconVariant.aws,
    _c[Provider.gcp] = AcmIcons_1.AcmIconVariant.gcp,
    _c[Provider.azure] = AcmIcons_1.AcmIconVariant.azure,
    _c[Provider.ibm] = AcmIcons_1.AcmIconVariant.ibm,
    _c[Provider.ibmpower] = AcmIcons_1.AcmIconVariant.ibmlogo,
    _c[Provider.ibmz] = AcmIcons_1.AcmIconVariant.ibmlogo,
    _c[Provider.baremetal] = AcmIcons_1.AcmIconVariant.baremetal,
    _c[Provider.vmware] = AcmIcons_1.AcmIconVariant.vmware,
    _c[Provider.hybrid] = AcmIcons_1.AcmIconVariant.hybrid,
    _c[Provider.other] = AcmIcons_1.AcmIconVariant.cloud,
    _c);
//# sourceMappingURL=index.js.map
